@@ -1,4 +1,5 @@
 # -*- coding: utf-8 -*-
+# pylint: disable=ungrouped-imports
 """Magnet Links
 ==================
 
@@ -7,18 +8,27 @@ handle magnet links.
 
 """
 
-import darc.typing as typing
+from typing import TYPE_CHECKING
+
 from darc.error import LinkNoReturn
-from darc.link import Link
 from darc.proxy.magnet import save_magnet
 from darc.sites._abc import BaseSite
 
+if TYPE_CHECKING:
+    from typing import NoReturn
+
+    from requests import Session
+    from selenium.webdriver import Chrome as Driver
+
+    from darc._compat import datetime
+    from darc.link import Link
+
 
 class Magnet(BaseSite):
     """Magnet links."""
 
     @staticmethod
-    def crawler(timestamp: typing.Datetime, session: typing.Session, link: Link) -> typing.NoReturn:  # pylint: disable=unused-argument
+    def crawler(timestamp: 'datetime', session: 'Session', link: 'Link') -> 'NoReturn':  # pylint: disable=unused-argument
         """Crawler hook for magnet links.
 
         Args:
@@ -34,7 +44,7 @@ class Magnet(BaseSite):
         raise LinkNoReturn(link)
 
     @staticmethod
-    def loader(timestamp: typing.Datetime, driver: typing.Driver, link: Link) -> typing.NoReturn:  # pylint: disable=unused-argument
+    def loader(timestamp: 'datetime', driver: 'Driver', link: 'Link') -> 'NoReturn':  # pylint: disable=unused-argument
         """Not implemented.
 
         Raises:
