@@ -22,7 +22,7 @@ copyright = '2019-2020, Jarry Shaw'
 author = 'Jarry Shaw'
 
 # The full version, including alpha/beta/rc tags
-release = '0.9.1'
+release = '0.9.3'
 
 
 # -- General configuration ---------------------------------------------------
@@ -36,6 +36,7 @@ extensions = [
     'sphinx.ext.autodoc', 'sphinx.ext.autodoc.typehints',
     'sphinx.ext.napoleon',
     'sphinx.ext.todo',
+    'sphinx_autodoc_typehints',
 ]
 
 intersphinx_mapping = {
@@ -76,7 +77,9 @@ napoleon_custom_sections = None
 
 manpages_url = 'https://linux.die.net/man/{section}/{page}'
 
-do_include_todos = True
+#do_include_todos = True
+
+set_type_checking_flag = True
 
 # Add any paths that contain templates here, relative to this directory.
 templates_path = ['_templates']
